Stan Math Library: stan/math/prim/scal/prob/neg_binomial_2_cdf_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
neg_binomial_2_cdf_log.hpp File Reference
`#include <stan/math/prim/scal/err/check_consistent_sizes.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`
`#include <stan/math/prim/scal/err/check_positive_finite.hpp>`
`#include <stan/math/prim/scal/meta/length.hpp>`
`#include <stan/math/prim/scal/meta/VectorBuilder.hpp>`
`#include <stan/math/prim/scal/meta/VectorView.hpp>`
`#include <stan/math/prim/scal/prob/beta_cdf_log.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_n , typename T_location , typename T_precision >
return_type< T_location, T_precision >::type | stan::math::neg_binomial_2_cdf_log (const T_n &n, const T_location &mu, const T_precision &phi)

[ Stan Home Page ] © 2011–2016, Stan Development Team.